==> bigloo_1.9c.orig.tar.gz: bigloo1.9c/runtime/Ieee/boolean.scm <==
;* --------------------------------------------------------------------*/
;*    Copyright (c) 1992-1998 by Manuel Serrano. All rights reserved.  */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \   /  '                               */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome. Send them to                                          */
;*        Manuel Serrano -- Manuel.Serrano@unice.fr                    */
;*-------------------------------------------------------------------- */
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/runtime1.9/Ieee/boolean.scm          */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Jan 20 08:34:45 1995                          */
;*    Last change :  Tue Aug 20 08:29:24 1996 (serrano)                */
;*    -------------------------------------------------------------    */
;*    6.1. Booleans (page 13, r4)                                      */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module __r4_booleans_6_1
   
   (use     (__type                    "Llib/type.scm")
	    (__error                   "Llib/error.scm")
	    (__bigloo                  "Llib/bigloo.scm")
	    (__tvector                 "Llib/tvector.scm")
	    (__r4_symbols_6_4          "Ieee/symbol.scm")
	    (__r4_vectors_6_8          "Ieee/vector.scm")
	    (__r4_pairs_and_lists_6_3  "Ieee/pair-list.scm")
	    (__r4_numbers_6_5_fixnum   "Ieee/fixnum.scm")
	    
	    (__evenv                   "Eval/evenv.scm"))
   
   (foreign (macro bool c-boolean? (obj)  "BOOLEANP")
	    (macro bbool btrue            "BTRUE")
	    (macro bbool bfalse           "BFALSE"))
   
   (export  (inline not::bool      ::obj)
	    (inline boolean?::bool ::obj))
   
   (pragma  (not side-effect-free)
	    (c-boolean? (predicate-of bbool) no-cfa-top)
	    (boolean? no-cfa-top side-effect-free)))

;*---------------------------------------------------------------------*/
;*    not ...                                                          */
;*---------------------------------------------------------------------*/
(define-inline (not obj)
   (if obj #f #t))

;*---------------------------------------------------------------------*/
;*    boolean? ...                                                     */
;*---------------------------------------------------------------------*/
(define-inline (boolean? obj)
   (c-boolean? obj))

==> bigloo_2.8c.orig.tar.gz: bigloo2.8c/runtime/Ieee/boolean.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/runtime/Ieee/boolean.scm             */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Jan 20 08:34:45 1995                          */
;*    Last change :  Fri Feb  4 10:04:06 2005 (serrano)                */
;*    -------------------------------------------------------------    */
;*    6.1. Booleans (page 13, r4)                                      */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module __r4_booleans_6_1
   
   (use     __type
	    __error
	    __bigloo
	    __tvector
	    __r4_symbols_6_4
	    __r4_strings_6_7
	    __r4_vectors_6_8
	    __r4_pairs_and_lists_6_3
	    __r4_numbers_6_5_fixnum
	    __r4_numbers_6_5_flonum
	    
	    __evenv)
   
   (extern  (macro c-boolean?::bool (::obj) "BOOLEANP")
	    (macro btrue::bbool "BTRUE")
	    (macro bfalse::bbool "BFALSE"))
   
   (java    (class foreign
	       (method static c-boolean?::bool (::obj) "BOOLEANP")
	       (field static btrue::bbool "BTRUE")
	       (field static bfalse::bbool "BFALSE")))
    
   (export  (inline not::bool ::obj)
	    (inline boolean?::bool ::obj))
   
   (pragma  (not side-effect-free nesting)
	    (c-boolean? (predicate-of bbool) no-cfa-top nesting)
	    (boolean? no-cfa-top side-effect-free nesting)))

;*---------------------------------------------------------------------*/
;*    not ...                                                          */
;*---------------------------------------------------------------------*/
(define-inline (not obj)
   (if obj #f #t))

;*---------------------------------------------------------------------*/
;*    boolean? ...                                                     */
;*---------------------------------------------------------------------*/
(define-inline (boolean? obj)
   (c-boolean? obj))
